
function [p] = arc(p1, p2, r, n, convex);

%ARC creates a set of points forming an arc of given radius that passes 
%    through two points
% 
% syntax:
% [p] = arc(p1, p2, r)
% [p] = arc(p1, p2, r, n)
% [p] = arc(p1, p2, r, n, convex)
%
% Arc is aproximated by polyline described by set of points p
%
% input:
% p1, p2 - two element vectors, coordinates of first and second points
% r      - number, radius of arc
% n      - number determining approximation of an arc, default 16
% convex - determined convexity of arc, if value equals 1 an arc is ploted
%          on the left side of the observer standing at the point p1 and
%          looking toward point p2, if value equals 0 an arc is ploitted 
%          on the right side, default 1
% 
% output:
% p - column matrix, set of points describing an arc
%
% examples:
% p = [[-1;0] arc([-1;1],[1,1],1) [1;0]];
% block_plot(prism(p,0.5))
% campos([[2.5 -0.5 1.5]])
% creates and plots a prism with rounded base
%
% See also: BLOCK, POLYLINE, PRISM
%

if ( nargin < 5 ) convex=1; end
if ( nargin < 4 ) n=16; end

if ( ~parIsVector(p1, 2) ) rethrow(geterr('argValVect', 'p1', 2)); end
if ( ~parIsVector(p2, 2) ) rethrow(geterr('argValVect', 'p2', 2)); end
if ( size(p1,2) > 1 ) p1=p1'; end
if ( size(p2,2) > 1 ) p2=p2'; end

p = arch(p1, p2, r, n, convex);

if ( p == 0 ) 
  p = [p1 p2];
  warning('ROBOT:arc', getwrn('blockArc', r)); 
end
