
function [val] = block_get(B, name)

%BLOCK_GET returns the value of the block's property
% 
% syntax:
% [val] = block_get(B, name)
%
% input:
% B    - structure representing a block
% name - block's property name, see function 'block'
%
% output:
% val - value of the property specified by 'name'
%
% example:
% b = pyramid(2,1,1)
% c = block_get(b, 'BlockColor')
% creates a new pyramid and gets its color
%
% See also: BLOCK, BLOCK_SET
%

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

lst = optlst('block');
[code, val, name] = checkopts(lst(:,1), name);

switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

val = blkget(B, name{1});
