
function [B] = block_plot(B, view)

%BLOCK_PLOT plots the block 
% 
% syntax:
% [B] = block_plot(B)
% [B] = block_plot(B, view)
%
% Parameters of the block are defined by its properties,
% see function 'block'.
%
% input:
% B    - a block to be plotted
% view - method of plotting, allowed values:
%        'mesh' - block is plotted as a grid
%        'surf' - block is plotted as a set of patches
%        default value 'mesh'
%
% output:
% B - structure representing a plotted block
%
% example:
% b = block_plot(pyramid(2,1,1))
% campos([-3,-3,1])
% creates and plots a pyramid, block is plotted as a grid
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, PRISM, PIRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_SET, BLOCK_GET, 
%           BLOCK_PLOT_CSYS, BLOCK_DELETE
%

if ( nargin < 2 ) view = 1; end;

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end
view = view2num(view, [1,2]);

hold on
B = blkplt(B, view);
hold off

if ( nargout == 0 ) clear B; end
