
function [B] = block_plot_csys(B)

%BLOCK_PLOT_CSYS plots the block's coordinate system
% 
% syntax:
% [B] = block_plot_csys(B)
%
% Parameters of the coordinate system are defined by properties of block,
% see function 'block'.
%
% input:
% B - a block which coordinate system is to be plotted
%
% output:
% B - structure representing a block with plotted coordinate system
%
% example:
% b = pyramid(2,1,1)
% b = block_plot(b)
% b = block_plot_csys(b)
% campos([-3,-3,1])
% creates a new pyramid and plots block and associated coordinate system
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, PRISM, PIRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_SET, BLOCK_GET, 
%           BLOCK_PLOT, BLOCK_DELETE
%

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

hold on
B = blkpltcsys(B);
hold off

if ( nargout == 0 ) clear B; end
