
function [B] = block_set(B, varargin)

%BLOCK_SET sets the values of the block's properties
% 
% syntax:
% [B] = block_set(B, 'PropertyName', PropertyValue, ...)
%
% input:
% B - structure representing a block
% property name/property value pairs are used to specify set properties,
% see function 'block'
%
% output:
% B - structure representing a block with fixed properties
%
% example:
% b = pyramid(2,1,1)
% b = block_set(b, 'BlockColor', 'r')
% creates a new pyramid with default properties and sets its color to red
%
% See also: BLOCK, BLOCK_GET
%

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

lst = optlst('block');
[code, val, arglst] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

opt = getopts(lst, arglst{:});
for i=1:2:length(arglst) 
  B = blkset(B, arglst{i}, getfield(opt,arglst{i}), 0); 
end
