
function [CS] = csys_delete(CS)

%CSYS_DELETE deletes the coordinate system
% 
% syntax:
% [CS] = csys_delete(CS)
%
% Function removes graphical representation of the coordinate system.
%
% input:
% CS - a coordinate system to be deleted
%
% output:
% CS - structure representing a coordinate system with removed graphical
%      representation
%
% example:
% axis([-3 3 -3 3 -3 3]);
% cs = csys(rp2t(rotz(pi/4),[0;0;0]))
% cs = csys_plot(cs)
% pause
% cs = csys_delete(cs)
% creates and plots a coordinate system (origin located in (0,0,0) point, 
% rotated around z-axis by pi/4 radians), after pressing any key graphical 
% representation of the coordinate system is removed
%
% See also: CSYS, CSYS_PLOT
%

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

delete(CS.fig.handle);
CS.fig.handle = [];

if ( nargout == 0 ) clear CS; end
