
function [val] = csys_get(CS, name)

%CSYS_GET returns the value of the coordinate system's property
% 
% syntax:
% [val] = csys_get(CS, name)
%
% input:
% CS   - structure representing coordinate system
% name - coordinate system's property name, see function 'csys'
%
% output:
% val - the value of the property specified by 'name'
%
% example:
% cs = csys(eye(4))
% c  = csys_get(cs, 'CSysColor')
% creates a new coordinate system and gets its color
%
% See also: CSYS, CSYS_SET
%

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

lst = optlst('csys');
[code, val, name] = checkopts(lst(:,1), name);

switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

val = csget(CS, name{1});
