
function [CS] = csys_plot(CS)

%CSYS_PLOT plots the coordinate system
% 
% syntax:
% [CS] = csys_plot(CS)
%
% Parameters of the coordinate system are defined by its properties,
% see function 'csys'.
%
% input:
% CS - a coordinate system to be ploted
%
% output:
% CS - structure representing a plotted coordinate system
%
% example:
% axis([-3 3 -3 3 -3 3]);
% cs = csys(rp2t(rotz(pi/4),[0;0;0]), 'CSysColor', 'r')
% cs = csys_plot(cs)
% creates and plots a coordinate system, its origin is located in (0,0,0) 
% point, system is rotated around z-axis by pi/4 radians
%
% See also: CSYS, CSYS_SET, CSYS_GET, CSYS_DELETE
%

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

hold on
CS.fig.handle = [CS.fig.handle csplt(CS.T, CS.axisLength, CS.label, CS.axisLabel, CS.fig.color, CS.fig.labelColor)];
hold off

if ( nargout == 0 ) clear CS; end
