
function [CS] = csys_set(CS, varargin)

%CSYS_SET sets the values of the coordinate system's properties
% 
% syntax:
% [CS] = csys_set(CS, 'PropertyName', PropertyValue, ...)
%
% input:
% CS - structure representing a coordinate system
% property name/property value pairs are used to specify fived properties,
% see function 'csys'
%
% output:
% CS - structure representing a coordinate system with fixed properties
%
% example:
% cs = csys(eye(4))
% cs = csys_set(cs, 'CSysColor', 'r')
% creates a new coordinate system with default properties and sets 
% its color to red
%
% See also: CSYS, CSYS_GET
%

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

lst = optlst('csys');
[code, val, arglst] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

opt = getopts(lst, arglst{:});
for i=1:2:length(arglst) 
  CS = csset(CS, arglst{i}, getfield(opt,arglst{i}), 0); 
end
