
function [B] = cube(a, varargin)

%CUBE creates a new cube with a given edge length
% 
% syntax:
% [B] = cube(a)
% [B] = cube(a, 'PropertyName', PropertyValue, ...)
%
% Block's base lies in xy-plane, point (0, 0, 0) is located in the center
% of the base.
%
% input:
% a - the length of cube's edge
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% example:
% b = cube(1)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cube with edges' length equal 1 and default properties
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(a,1) ) rethrow(geterr('argValNum','a')); end

B = cuboid(a, a, a, varargin{:});
