
function [B] = cuboid(a, b, h, varargin)

%CUBOID creates a new rectangular cuboid with the given parameters
% 
% syntax:
% [B] = cuboid(a, b, h)
% [B] = cuboid(a, b, h, 'PropertyName', PropertyValue, ...)
%
% Block's base lies in xy-plane, point (0, 0, 0) is located in the center
% of the base.
%
% input:
% a, b - the lengths of base's edges
% h    - the height of cuboid
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% example:
% b = cuboid(2, 3, 5)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cuboid with base's edges length equal 2 and 3, 
% and height equals 5, all properties are default 
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(a,1) ) rethrow(geterr('argValNum','a')); end
if ( ~parIsVector(b,1) ) rethrow(geterr('argValNum','b')); end
if ( ~parIsVector(h,1) ) rethrow(geterr('argValNum','h')); end

a2 = a/2;  b2 = b/2;
p = [ [-a2; -b2] [a2; -b2] [a2; b2] [-a2; b2] ];

[p, f] = add3dim(p, h);

B = block(p, f, varargin{:});
