
% ------------------------------------------------------------------------
% DEMO3P_3
% Demo program of ROBOT toolbox
% 3P type robot, 3D view defined by user
% Panel allows to change configuration of the robot
% ------------------------------------------------------------------------

% configuration variables

d1 = 5;
d2 = 7;
d3 = 3;

% robot's definition
% base is rotated around x-axis by -pi/2 radians
% grasper is placed along z-axis of the last joint's coordinale system, 
% its length equals 3 units

r = robot([0 0 d1 0; pi/2 0 d2 -pi/2; -pi/2 2 d3 0], ['p', 'p', 'p'],...
          'RobotBase', rp2t(rotx(-pi/2),[0;0;0]),...
          'RobotGrasper', rp2t(roty(-pi/2),[0; 0; 3]),...
          'RobotRange', [-3.5, 8.5; 1, 11; 0, 6]);

% definition of apperance of robot's arms

% base (joint 0) - one block (cuboid with U-shape base)
b1 = block_move(prism([[-2.5;0] [-2.5;2] [2.5;2] [2.5;0] [1.5;0] [1.5;1] [-1.5;1] [-1.5;0]],15), [0;0;-5]);
r  = robot_arm(r, 0, b1);

% first joint - two blocks (square base and pilar)
b1 = block_move(cuboid(3,3,1), rp2t(rotx(pi/2),[0;1;0]));
b2 = block_move(cuboid(1,1,13), rp2t(rotx(pi/2),[0;0;0]));
r  = robot_arm(r, 1, b1, b2);

% second joint - one block (cuboid)
b1 = block_move(prism([[-1;-1] [3;-1] [3;1] [-1;1]],2), [0;0;-1]);
r  = robot_arm(r, 2, b1);

% third joint and grasper (first variant of definition) 
% blocks defined in the third joint's coordinate system
% two blocks (cuboid - joint, prism - grasper)
% b1 = block_move(cuboid(1,1,9), [0;0;-8]);
% b2 = block_move(prism([[0;1.5] [0;-1.5] [.5;-1.5] [2;-1] [.5;-1] [.5;1] [2;1] [.5;1.5]],1), rp2t(roty(-pi/2),[0.5;0;1]));
% r  = robot_arm(r, 3, b1,b2);

% third joint (second variant of definition) 
% one block (cuboid) defined in the third joint's coordinate system
b1 = block_move(cuboid(1,1,9), rp2t(eye(3),[0;0;-8]));
r  = robot_arm(r, 3, b1);

% grasper (second variant of definition)
% one block (prism) defined in the grasper's coordinate system
b1 = block_move(prism([[0;1] [0;-1] [.5;-1.15] [1.75;-0.6] [.5;-0.6] [.5;0.6] [1.75;0.65] [.5;1.15]],1), [-2;0;-0.5]);
r  = robot_arm(r, 4, b1);


% global coordinate system

axis([-8 10 -6 12 -2 14])
csys_plot(csys(eye(4), 'CSysAxisLength', axis));

% robot (plotted in view 'mesh'), its coordinate systems (all visible) and panel

r = robot_plot(r, 'mesh');
r = robot_plot_csys(r,1,1,1);
robot_panel(r);

grid on
