
% ------------------------------------------------------------------------
% DEMO3PR_3
% Demo program of ROBOT toolbox
% 3PR type robot, 3D view defined by user
% Panel allows to change configuration of the robot
% ------------------------------------------------------------------------

% configuration variables

d1=5;
d2=5;
d3=3;
t4=0;

% robot's definition
% base is rotated around x-axis and z-axis by -pi/2 radians, and moved along z-axis by 5 units
% grasper is placed along z-axis of the last joint's coordinale system, its length equals 2 units

r = robot([dh(0,0,d1,0); dh(-pi/2,0,d2,pi/2); dh(-pi/2,1,d3,0); dh(0,0,1,t4)], ['p','p','p','r'],...
          'RobotBase', rp2t(rotx(-pi/2)*rotz(-pi/2),[0;0;5]),... 
          'RobotGrasper', rp2t(roty(-pi/2),[0; 0; 2]),...
          'RobotRange', [0, 10; 1, 10; 0, 5; -pi, pi]);

% definition of apperance of robot's arms

par1 = {'BlockColor',[0,0.5,0.75],'BlockEdgeColor','none'};
par2 = {'BlockColor',[0.25,0.5,0.75],'BlockEdgeColor','none'};
par3 = {'BlockColor',[1,1,0.5],'BlockEdgeColor','none'};

% base (joint 0) - two blocks (rectangular beams along which the manipulator moves)
b1 = block_move(cuboid(0.5,0.5,12,par1{:}), rp2t(eye(3),[0;0;-1]));
b2 = block_move(cuboid(0.5,0.5,12,par1{:}), rp2t(eye(3),[0;11;-1]));
r  = robot_arm(r, 0, b1, b2);

% first joint - three blocks (rectangular beam with two cubes at the ends moving along base)
b1 = block_move(cube(1,par2{:}), rp2t(eye(3),[0;0;-0.5]));
b2 = block_move(cube(1,par2{:}), rp2t(eye(3),[0;11;-0.5]));
b3 = block_move(cuboid(0.5,0.5,10,par2{:}), rp2t(rotx(-pi/2),[0;0.5;0]));
r  = robot_arm(r, 1, b1, b2, b3);

% second joint - one block (cuboid moving along first joint)
b = block_move(cuboid(2,1,1,par2{:}), rp2t(eye(3),[0.5;0;-0.5]));
r = robot_arm(r, 2, b);

% third joint - obe block (cylinder)
b = block_move(cylinder(0.35,6,16,par2{:}), rp2t(eye(3),[0;0;-6]));
r = robot_arm(r, 3, b);

% fourth joint and grasper (first variant of definition) 
% blocks defined in the fourth joint's coordinate system
% two blocks (cylinder - joint, prism - grasper)
% b1 = block_move(cylinder(0.3,1,16,par3{:}), rp2t(eye(3),[0;0;-1]));
% b2 = block_move(prism([[0;1] [0;-1] [.5;-1] [2;-0.5] [.5;-0.5] [.5;0.5] [2;0.5] [.5;1]],0.6,par3{:}), rp2t(roty(-pi/2),[0.3;0;0]));
% r  = robot_arm(r, 4, b1, b2);

% fourth joint (second variant of definition) 
% one block (cylinder) defined in the fourth joint's coordinate system
b = block_move(cylinder(0.3,1,16,par3{:}), rp2t(eye(3),[0;0;-1]));
r  = robot_arm(r, 4, b);

% grasper (second variant of definition)
% one block (prism) defined in the grasper's coordinate system
b = block_move(prism([[0;0.5] [0;-0.5] [.5;-0.75] [2;-0.35] [.5;-0.35] [.5;0.35] [2;0.35] [.5;0.75]],0.6,par3{:}), rp2t(eye(3),[-2;0;-0.3]));
r  = robot_arm(r, 5, b);


% global coordinate system

axis([-5 15 -5 15 -5 15])
csys_plot(csys(eye(4), 'CSysAxisLength', axis));

% robot (plotted in view 'surf'), and panel

r = robot_plot(r, 'surf');
robot_panel(r)

camlight
grid on
