
% ------------------------------------------------------------------------
% DEMO3R_3
% Demo program of ROBOT toolbox
% Planar, 3R type robot, 3D view defined by user
% Panel allows to change configuration of the robot
% ------------------------------------------------------------------------

% configuration variables

t1 = -pi/4;
t2 =  pi/2;
t3 = -pi/4;

% robot's definition
% base is rotated around x-axis by -pi/2 radians
% grasper is parallel to the x-axis of the last joint's coordinale system, 
% its length equals 0.15 units

r = robot( [dh(0,0,0,t1); dh(0,0.4,0,t2); dh(0,0.36,0,t3)], ['r', 'r', 'r'],...
           'RobotBase', rp2t(rotx(-pi/2),[0;0;0]),...
           'RobotGrasper', [0.15; 0; -0.025],...
           'RobotRange', [-pi, pi/4; -3*pi/4, 3*pi/4; -3*pi/4, 3*pi/4],...
           'CSysAxisLength', [0 0.1 0 0.1 0 0.1]);


% definition of apperance of robot's arms

par1 = {'BlockColor',[0,1,0],'BlockEdgeColor','none'};
par2 = {'BlockColor',[1,1,0],'BlockEdgeColor','none'};
par3 = {'BlockColor',[0,0.75,0],'BlockEdgeColor','none'};
par4 = {'BlockColor',[0.75,0.75,0.75],'BlockEdgeColor','none'};

nr = 25;

% base (joint 0) - two blocks (square base and rounded prism)
fi= 0.05 : -(pi-0.1)/nr : -pi-0.05;  x = 0.048*cos(fi);  y = 0.048*sin(fi);
p = [x(1)+0.01 x x(length(x))-0.01; 0.07 y 0.07];
b1 = block_move(cuboid(0.2,0.2,0.025,par1{:}), rp2t(rotx(pi/2),[0;0.07+0.025;0]));
b2 = block_move(prism(p,0.05,par1{:}), [0;0;-0.05]);
r = robot_arm(r, 0, b1, b2);

% first joint - two blocks (cylinder-axis of rotation, rounded prism-joint)
fi=pi/2:pi/nr:3*pi/2;  x1 = 0.048*cos(fi);  y1 = 0.048*sin(fi);
fi=-pi/2:pi/nr:pi/2;   x2 = 0.036*cos(fi);  y2 = 0.036*sin(fi);
p = [x1 x2+0.4; y1 y2];
b1 = prism(p,0.05,par2{:});
b2 = block_move(cylinder(0.01,0.11,par3{:}), [0;0;-0.055]);
r = robot_arm(r, 1, b1, b2);
 
% second joint - two blocks (cylinder-axis of rotation, rounded prism-joint)
fi =  pi/2:pi/nr:3*pi/2;  x1 = 0.036*cos(fi);  y1 = 0.036*sin(fi);
fi = -pi/2:pi/nr:pi/2;    x2 = 0.012*cos(fi);  y2 = 0.012*sin(fi);
p = [x1 x2+0.36; y1 y2];
b1 = block_move(prism(p,0.05,par2{:}), [0;0;-0.05]);
b2 = block_move(cylinder(0.01,0.11,par3{:}), [0;0;-0.055]);
r = robot_arm(r, 2, b1, b2);

% third joint - two blocks (cylinders - axis of rotation and joint)
b1 = block_move(cylinder(0.012,0.1,nr,par2{:}), rp2t(roty(pi/2),[0;0;-0.025]));
b2 = block_move(cylinder(0.005,0.06,par3{:}), [0;0;-0.055]);
r = robot_arm(r, 3, b1, b2);

% grasper - two blocks (cylinder and prism)
b1 = block_move(cylinder(0.012,0.025,nr,par4{:}), rp2t(roty(-pi/2),[-0.025;0;0]));
b2 = block_move(prism([[0.025;0] [0.025;0.025] [0.0125;0.05] [0.0125;0.0125] [-0.0125;0.0125] [-0.0125;0.05] [-0.025;0.025] [-0.025;0]],0.012,...
    par4{:}), rp2t(rotz(-pi/2),[-0.025;0;-0.006]));
r = robot_arm(r, 4, b1, b2);

% global coordinate system

axis([-0.5 1 -0.75 0.75 -0.5 1])
csys_plot(csys(eye(4), 'CSysAxisLength', axis));

% robot (plotted in view 'surf'), its coordinate systems (all visible) and panel

r = robot_plot(r, 'surf');
r = robot_plot_csys(r, 1, 1, 1);
robot_panel(r)

camlight;
grid on
