
% ------------------------------------------------------------------------
% DEMOPUMA_3
% Demo program of ROBOT toolbox
% PUMA type robot, 3D view defined by user
% Panel allows to change configuration of the robot
% ------------------------------------------------------------------------

% configuration variables

t1 =  0;
t2 = -pi/4;
t3 =  pi/4;
t4 =  0;
t5 =  pi/4;
t6 =  0;

% robot's definition

d2 = 243.5/1000; d3 = -93.4/1000; d4 = -20.3/1000; l2 = 431.8/1000; l3 = 433.1/1000; lt=200.0/1000;
DH = [dh(0,0,0,t1); dh(-pi/2,0,d2,t2); dh(0,l2,d3,t3); dh(pi/2,l3,d4,t4); dh(-pi/2,0,0,t5); dh(pi/2,0,0,t6);];

r = robot(DH, ['r', 'r', 'r', 'r', 'r', 'r'],...
         'RobotGrasper', [0.1; 0; 0],...
         'CSysAxisLength', [0 0.25 0 0.25 0 0.25]);

% definition of apperance of robot's arms
 
nr = 128;
par1 = {'BlockColor', [0.5, 0.75, 1], 'BlockEdgeColor', 'none'};
par2 = {'BlockColor', [0.45, 0.7, 0.95], 'BlockEdgeColor', 'none'};
par3 = {'BlockColor', [0.75, 0.75, 0], 'BlockEdgeColor', 'none'};

% base (joint 0) - two blocks (cylinders - circular base and pilar)
b1 = block_move(cylinder(0.2032,0.04750,nr,par1{:}), rp2t(eye(3),[0;0;-0.6718]));
b2 = block_move(cylinder(0.0900,0.59687,nr,par1{:}), rp2t(eye(3),[0;0;-0.6718]));
r = robot_arm(r, 0, b1, b2);

% first joint - two blocks (cylinders)
b1 = block_move(cylinder(0.07493,0.07493,nr,par1{:}), rp2t(eye(3),[0;0;-0.07493]));
b2 = block_move(cylinder(0.07493,d2+0.07493-d3/2+0.005,nr,par1{:}), rp2t(rotx(-pi/2),[0;-0.07493;0]));
r = robot_arm(r, 1, b1, b2);

% second joint - one block (user defined prism)
fi=150*pi/180 : 60*pi/180/nr : 210*pi/180; 
x = 0.2308*cos(fi); y = 0.2308*sin(fi);
x = [x(length(x))+0.2154 x x(length(x))+0.2154]; y = [y(1) y y(length(y))];
fi=-pi/2:pi/nr:pi/2; 
x = [x 0.0692*cos(fi)+l2]; y = [y 0.0692*sin(fi)+0.01286];
b1 = block_move(prism([x;y],-d3,par1{:}), rp2t(eye(3),[0;0;d3/2]));
r = robot_arm(r, 2, b1);
 
% third joint - three blocks (user defined prism and cuboid - joint, cylinder - axis of rotation)
fi=140*pi/180 : 80*pi/180/nr : 220*pi/180; 
x = 0.1158*cos(fi); y = 0.1158*sin(fi);
x = [x l3-0.0417 l3-0.0417]; y = [y -0.0417 0.0417];
b1 = block_move(prism([x;y],-d3,par1{:}), rp2t(eye(3),[0;0;d3/2]));
b2 = block_move(cuboid(0.0417,2*0.0417,-d3,par1{:}), rp2t(eye(3),[l3-0.0417/2;0;d3/2]));
b3 = block_move(cylinder(0.03,-2*d3+0.01,nr,par2{:}), rp2t(eye(3),[0;0;d3/2-0.005]));
r = robot_arm(r, 3, b1, b2, b3);

% fourth and fifth join - empty

% sixth joint and tool - two blocks (sphere - joint, cylinder - tool)
b1 = sphere(0.0417,nr/4,par1{:});
b2 = block_move(cylinder(0.015,lt,nr,par3{:}), rp2t(roty(pi/2),[0;0;0]));
r = robot_arm(r, 6, b1, b2);

 
% global coordinate system

axis([-0.5 1 -0.75 0.75 -0.75 0.75])
%csys_plot(csys(eye(4), 'CSysAxisLength', axis));

% robot (plotted in view 'surf'), its coordinate systems (all visible) and panel

r = robot_plot(r, 'surf');
%r = robot_plot_csys(r, 1, 0, 1);
robot_panel(r);

camlight;
grid on;
