
% ------------------------------------------------------------------------
% DEMO_TRJ
% Demo program of ROBOT toolbox
% RPR type manipulator moving block
% ------------------------------------------------------------------------

q1 = [-pi/2;1;pi/2];   % start configuration
q2 = [-pi/2;3;pi/2];   % intermediate configuration - manipulator catches the block
q3 = [-pi;3;0];        % final configuration - manipulator drops the block
q4 = [-pi;2.25;0];     % intermediate configuration - manipulator returns to start configuration
                       % avoiding the block

% manipulator's and block's definition

r = robot([dh(0,0,2,q1(1)); dh(-pi/2,0,q1(2),0); dh(0,0,1,q1(3))], ['r', 'p', 'r'],...
          'RobotGrasper', rp2t(roty(-pi/2),[0;0;0.5]),...
          'RobotGrasperSize', 1,...
          'RobotRange', [-pi, pi; 0, 4; -pi, pi],...
          'RobotCylinderRadius', 0.25,...
          'RobotCylinderApprox', 16,...
          'RobotColor', [0,0.25,0.65],...
          'RobotGrasperColor', [0,0.5,1],...
          'RobotExColor', 'g',...
          'RobotEdgeColor', 'none',... 
          'RobotModel', 'rangeex');
      
b = cuboid(0.5,0.5,2,'BlockColor','y','BlockEdgeColor',[0.75,0.75,0]);
b = block_move(b, rp2t(eye(3),[5.125;0;1]));

% global coordinate system, manipulator and block in start position

clf
axis([-4 6 -6 4 -2 6])
grid on
csys_plot(csys(eye(4), 'CSysAxisLength', axis));
camlight
b = block_plot(b, 'surf');
b = block_plot_csys(b);
r = robot_plot(r, 'surf');
h = text(-5,0,6,'Press any key...');
pause;  delete(h);
 
% first part of task: manipulator catches a block
 
[q,v,t] = trajectory(0:0.025:2, q1, q2, 'poly3');
r = robot_motion(r, q);
r = robot_catch(r, b);

% second part of task: manipulator moves the block and drops it in final position
 
[q,v,t] = trajectory(0:0.025:3, q2, q3, 'poly3');
r = robot_motion(r, q);
r = robot_drop(r);
 
% third part of task: manipulator returns to start position avoiding the block
 
[q,v,t] = trajectory(0:0.025:1.5, q3, q4, 'poly3');
r = robot_motion(r, q);
[q,v,t] = trajectory(0:0.025:1.5, q4, q1, 'poly3');
r = robot_motion(r, q);
