
function [B] = prism(p, h, varargin)

%PRISM creates a new prism with the given parameters
% 
% syntax:
% [B] = prism(p, h)
% [B] = prism(p, h, 'PropertyName', PropertyValue, ...)
%
% Block's base (specified by 'p') lies in xy-plane. 
% 
% input:
% p - a column matrix containing the x, y coordinates for base's vertices
% h - the height of prism
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% example:
% b = prism([[1;0] [0;1] [-1;0] [0;-1]], 3)
% block_plot(b)
% campos([-1,-3,1])
% creates and prints a prism with square base and height equals 3, 
% all properties are default 
%
% See also: ARC, BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsMatrix(p,2,0) ) rethrow(geterr('argValMtx1','p',2)); end
if ( ~parIsVector(h,1)   ) rethrow(geterr('argValNum','h')); end

[p, f] = add3dim(p, h);

B = block(p, f, varargin{:});