
function [R] = rset(R, name, val, init)

refresh = 1;

switch ( name )
      
  case 'RobotBase'

    if ( parIsMatrix(val,3,1) ) R.base=rp2t(eye(3), val);
    elseif ( parIsMatrix(val,4,4) ) R.base=val;
    else rethrow(geterr('propValMtx',name,4,4)); end
    refresh = 0;

  case 'RobotGrasper'

    if ( parIsMatrix(val,3,1) ) R.grasper=rp2t(eye(3), val);
    elseif ( parIsMatrix(val,4,4) ) R.grasper=val;
    else rethrow(geterr('propValMtx',name,4,4)); end
    
  case 'RobotGrasperSize'

    if ( parIsVector(val,1) ) R.grasperSize=[val, val];
    elseif ( parIsVector(val,2) ) R.grasperSize=val;
    else rethrow(geterr('propValVect',name,2)); end

  case 'RobotRange'
        
    if ( init & isempty(val) )
      val = [ -Inf*ones(R.n,1) Inf*ones(R.n,1) ];
    elseif (( ~init & isempty(val) ) | ~parIsMatrix(val,R.n,2) )
       rethrow(geterr('propValMtx',name,R.n,2));
    end
    
    for i=1:R.n
      if ( val(i,1) > val(i,2) )
        v=val(i,2); val(i,2)=val(i,1); val(i,1)=v;
        warning('ROBOT:robotRange1', getwrn('robotRange1', i, val(i,1), val(i,2)))
      end
      if ( R.joints(i) == 'r' ) nr=4;  else nr=3; end
      if ( R.dh(i,nr) < val(i,1) ) 
        R.dh(i,nr) = val(i,1);
        warning('ROBOT:robotRange2', getwrn('robotRange2', i, R.dh(i,nr)))
      elseif( R.dh(i,nr) > val(i,2) )
        R.dh(i,nr) = val(i,2);
        warning('ROBOT:robotRange2', getwrn('robotRange2', i, R.dh(i,nr)))
      end
    end
    
    R.range = val;

  case 'RobotLineWidth',
    if ( parIsVector(val,1) ) R.plain.lineWidth = val;
    else rethrow(geterr('propValNum',name)); end

  case 'RobotColor',
    if ( iscell(val) )
      if ( length(val) < 4 ) rethrow(geterr('propValRColor',name)); end
    else val = { val, val, val, val }; end
    R.fig.color = val;

  case 'RobotLengthColor'
    if ( ~strcmp(val,'_null') ) R.fig.color{1}=val; end
  
  case 'RobotOffsetColor'
    if ( ~strcmp(val,'_null') ) R.fig.color{2}=val; end;
  
  case 'RobotGrasperColor'
    if ( ~strcmp(val,'_null') ) R.fig.color{3}=val; end;
  
  case 'RobotExColor'
    if ( ~strcmp(val,'_null') ) R.fig.color{4}=val; end;

  case 'RobotEdgeColor',
    if ( iscell(val) )
      if ( length(val) < 4 ) rethrow(geterr('propValRColor',name)); end
    else val = { val, val, val, val }; end
    R.fig.edgeColor = val;
  
  case 'RobotLengthEdgeColor'
    if ( ~strcmp(val,'_null') ) R.fig.edgeColor{1}=val; end;
  
  case 'RobotOffsetEdgeColor'
    if ( ~strcmp(val,'_null') ) R.fig.edgeColor{2}=val; end;
  
  case 'RobotGrasperEdgeColor'
    if ( ~strcmp(val,'_null') ) R.fig.edgeColor{3}=val; end;
  
  case 'RobotExEdgeColor'
    if ( ~strcmp(val,'_null') ) R.fig.edgeColor{4}=val; end;

  case 'RobotCylinderRadius'
      
    if ( parIsVector(val,1) ) R.def3d.cylinderRadius = val;
    else rethrow(geterr('propValNum',name)); end

  case 'RobotCylinderApprox'
      
    if ( parIsVector(val,1) ) R.def3d.cylinderApprox = val;
    else rethrow(geterr('propValNum',name)); end

  case 'RobotModel'
      
    if ( ~parIsVectorTxt(val) ) rethrow(geterr('propValTxt',name));
    elseif ( ~parIsText(val,{'config','configex','range','rangeex'}) ) 
      rethrow(geterr('propVal',name,'config, configex, range, rangeex')); 
    end
    
    if ( any(any(abs(R.range)==Inf)) ) 
      if ( strcmpi(val,'range') )
        val = 'config';
        warning('ROBOT:robotModel', getwrn('robotModel', 'range', 'config'))
      elseif ( strcmpi(val,'rangeex') )
        val = 'configex';
        warning('ROBOT:robotModel', getwrn('robotModel', 'rangeex', 'configex'))
      end
    end
    
    R.def3d.model=lower(val);

  case 'CSysAxisLength'
      
    if ( parIsVector(val,6) ) R.csys.axisLength = val;
    else rethrow(geterr('propValVect',name,6)); end
    refresh = 0;

  case 'CSysColor'
      
    R.csys.color = val;
    refresh = 0;
  
  case 'CSysLabelColor'
      
    R.csys.labelColor = val;
    refresh = 0;
  
  case 'CSysLabel'
  
    if ( strcmp(val, 'default') ) 
      val = {};  val{1} = '0';
      for i=1:R.n val{i+1}=sprintf('%1d', i); end
      val{R.n+2} = 'G';
    elseif ( isempty(val) )
      for i=1:R.n+2 val{i}=''; end
    elseif ( ~parIsCellTxt(val,R.n+2) ) rethrow(geterr('propValCellTxt',name,R.n+2)); end

    R.csys.label = val;
    refresh = 0;

  case 'CSysAxisLabel'
  
    if ( strcmp(val, 'default') ) val = {'x', 'y', 'z'}; 
    elseif ( isempty(val) ) val = {'', '', ''}; 
    elseif ( ~parIsCellTxt(val,3) ) rethrow(geterr('propValCellTxt',name,3)); end

    R.csys.axisLabel = val;
    refresh = 0;
    
    for i=1:R.n+2
      for j=1:3
        R.csys.axisLabels{i, j} = val{j};
        if ( ~isempty(val{j}) & ~isempty(R.csys.label{i}) ) 
          R.csys.axisLabels{i, j} = [R.csys.axisLabels{i, j}, '_', R.csys.label{i}];
        end
      end  
    end

end

if ( refresh & ~init ) 
  R.def3d.blocks = rdef3d(R);
end

