
function [B] = pyramid(a, b, h, varargin)

%PYRAMID creates a new pyramid with the given parameters
% 
% syntax:
% [B] = pyramid(a, b, h)
% [B] = pyramid(a, b, h, 'PropertyName', PropertyValue, ...)
%
% Block's base is a rectangle and lies in xy-plane, point (0, 0, 0) is 
% located in the center of the base.
%
% input:
% a, b - the lengths of base's edges
% h    - teh height of pyramid
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% example:
% b = pyramid(1, 2, 3)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a pyramid with base's edges length equal 1 and 2, 
% and height equal 5, all properties are default 
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(a,1) ) rethrow(geterr('argValNum','a')); end
if ( ~parIsVector(b,1) ) rethrow(geterr('argValNum','b')); end
if ( ~parIsVector(h,1) ) rethrow(geterr('argValNum','h')); end

a2 = a/2;  b2 = b/2;
p = [ [-a2; -b2; 0] [a2; -b2; 0] [a2; b2; 0] [-a2; b2; 0] [0; 0; h] ];
% e = [ [1; 2] [2; 3] [3; 4] [4; 1] [1; 5] [2; 5] [3; 5] [4; 5] ]';
f = { [1 2 3 4] [1 2 5] [2 3 5] [3 4 5] [4 1 5] };

B = block(p, f, varargin{:});
