
function [R]=robot_catch(R, B)

%ROBOT_CATCH 'catches' a block, i.e. connects a block with a robot
% 
% syntax:
% [R] = robot_catch(R, B)
% 
% Function places a block in grasper coordinate system, a robot's
% movement will cause displacement of the block.
%
% input:
% R - a structure representing a robot
% B - a block to catch
%
% output:
% R - structure representing a robot with 'catched' block
%
% example:
% axis([-1 5 -1 5 -3 3]);
% campos([-1 -1 3]);
% r = robot([dh(0,0,0,0)], ['r'], 'RobotGrasper', [4;0;0]);
% r = robot_plot(r);
% r = robot_plot_csys(r,1,0,1);
% pause
% b = block_move(cube(0.8),[4;0;-0.4]);
% b = block_plot(b);
% r = robot_catch(r,b);
% pause
% r = robot_motion(r,[pi/2]);
% creates a robot with one revolute joint, plots a robot with its coordinates systems,
% after pressing any key creates and plots a block which is catched by robot,
% after pressing any key a robot moves to new configuration moving a block
%
% See also: ROBOT, ROBOT_DROP, ROBOT_PLOT, ROBOT_MOTION, 
%           BLOCK, BLOCK_PLOT
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

T = trans2(R.dh, R.base);
R.tblock = invt(T{R.n}*R.grasper)*B.T;
R.cblock = B;
