
function [R]=robot_drop(R)

%ROBOT_DROP 'dropes' a block catched by 'robot_catch', 
%           i.e. disconnects a block and a robot
% 
% syntax:
% [R] = robot_drop(R)
%
% input:
% R - a structure representing a robot holding a block
%
% output:
% R - structure representing a robot without a block
%
% example:
% axis([-1 5 -1 5 -3 3]);
% campos([-1 -1 3]);
% r = robot([dh(0,0,0,0)], ['r'], 'RobotGrasper', [4;0;0]);
% r = robot_plot(r);
% r = robot_plot_csys(r,1,0,1);
% b = block_move(cube(0.8),[4;0;-0.4]);
% b = block_plot(b);
% r = robot_catch(r,b);
% pause
% r = robot_motion(r,[pi/2]);
% pause
% r = robot_drop(r);
% r = robot_motion(r,[0]);
% creates a robot with one revolute joint, plots a robot with its coordinates systems,
% creates and plots a block which is catched by robot,
% after pressing any key a robot moves to new configuration moving a block,
% after pressing any key a robot drops a block and returns to start configuration
%
% See also: ROBOT, ROBOT_CATCH, ROBOT_PLOT, ROBOT_MOTION, 
%           BLOCK, BLOCK_PLOT
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

R.cblock = [];
R.tblock = [];
