
function [val] = robot_get(R, name)

%ROBOT_GET returns the value of the robot's property
% 
% syntax:
% [val] = robot_get(R, name)
%
% input:
% R    - structure representing a robot
% name - robot's property name, see function 'robot'
%
% output:
% val - value of the property specified by 'name'
%
% example:
% r = robot([dh(0,0,0,-pi/4); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r']);
% c = robot_get(r, 'RobotColor')
% creates a planar manipulator with three revolute kinematics pairs 
% and gets its current color
%
% See also: ROBOT, ROBOT_SET
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

lst = optlst('robot');
[code, val, name] = checkopts(lst(:,1), name);
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

val = rget(R, name{1});
