
function robot_panel(par)

%ROBOT_PANEL shows panel which allows to change configuration of the robot 
%            in figure window
% 
% syntax:
% robot_panel(R)
% robot_panel(switch)
%
% The panel contains slider control for each robot joint. Limits of the
% sliders results from "RobotRange" property (see function Robot), if this
% property is undefined function takes following default values: -pi..pi
% for revolute joint and 0..10 for prismatic joint.
%
% input:
% R      - structure representing a robot
% switch - determines operation performed on panel, available only after
%          calling the function with "robot" parameter, allowed values:
%          'on'    - shows a panel
%          'off'   - hides a panel
%          'close' - removes a panel from window
%
% example:
% axis([-5 15 -10 10 -5 10])
% csys_plot(csys(eye(4), 'CSysAxisLength', axis));
% r = robot( [dh(0,0,0,-pi/4); dh(0,7,0,pi/2); dh(0,7,0,-pi/4)], ['r', 'r', 'r'],...
%     'RobotBase', rp2t(rotx(-pi/2),[0;0;0]), 'RobotGrasper', [3; 0; 0],...
%     'RobotRange', [-pi/2 0; -pi pi; -pi pi]);
% r = robot_plot(r, 'line');
% robot_panel(r)
% creates a robot with three revolute joints, plots a robot and shows a panel
%
% See also: ROBOT, ROBOT_PLOT
%

if ( ischar(par) )
  if ( ~strcmpi(par,'on') & ~strcmpi(par,'off') & ~strcmpi(par,'close') ) 
    rethrow('argAllowed','switch','on, off, close'); end
elseif ( ~parIsObj(par,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

ud = get(gcf(), 'UserData');
if ( parIsObj(par,'robot') ) 
  rpnl('close', par);
  rpnl('init', par);
elseif ( strcmpi(par, 'on' )   ) rpnl('show');
elseif ( strcmpi(par, 'off')   ) rpnl('hide'); 
elseif ( strcmpi(par, 'close') ) rpnl('close'); end
