
function [T]=rp2t(R, P)

%RP2T creates a transformation matrix using a rotation matrix and
%     a translation vector
% 
% syntax:
% [T] = rp2t(R, P)
%
% input:
% R - a rotation matrix
% P - a translation vector
%
% output:
% T - 4x4 transformation matrix
%
% example:
% t = rp2t(rotx(pi/2),[1;0;0])
% creates a transformation matrix describing a rotation around x-axis 
% by pi/2 radians and translation along x-axis by 1 unit
%
% See also: ROTX, ROTY, ROTZ, TINV
%

if ( ~parIsMatrix(R,3,3) ) rethrow(geterr('argValMtx','R',3,3)); end
if ( ~parIsVector(P,3)   ) rethrow(geterr('argValVect','P',3)); end

if ( size(P,1) == 1 ) P=P'; end

T = [R P; 0 0 0 1];
