
function [B] = tetrahedron(a, varargin)

%TETRAHEDRON creates a new tetrahedron with the given parameters
% 
% syntax:
% [B] = tetrahedron(a)
% [B] = tetrahedron(a, 'PropertyName', PropertyValue, ...)
%
% Block's base lies in xy-plane, point (0, 0, 0) is located in the center 
% of the base.
%
% input:
% a - the length of block's edges
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% example:
% b = tetrahedron(2)
% block_plot(b)
% campos([-1,-3,1.5])
% creates and plots a tetrahedron with length of edges equal 2, 
% all properties are default 
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(a,1) ) rethrow(geterr('argValNum','a')); end

h=a*sqrt(3)/2; r=2/3*h; r2=r/2;  a2=a/2;  H=a*sqrt(2/3);

p = [ [r; 0; 0] [-r2; a2; 0] [-r2; -a2; 0] [0; 0; H] ];
% e = [ [1; 2] [2; 3] [3; 1] [1; 4] [2; 4] [3; 4] ]';
f = { [1 2 3] [1 2 4] [2 3 4] [1 3 4] };

B = block([p; ones(1,size(p,2))], f, varargin{:});
