
function [T]=tinv(T)

%TINV creates an inverse transformation matrix
% 
% syntax:
% [T] = tinv(T)
%
% input:
% T - 4x4 transformation matrix
%
% output:
% T - an inverse transformation matrix
%
% example:
% t1 = rp2t(rotx(pi/2),[1;0;0]);
% t2 = tinv(t1);
% creates a transformation matrix (t1) describing a rotation around 
% x-axis by pi/2 radians and translation along x-axis by 1 unit, 
% and inverse transformation matrix (t2) describing a rotation around 
% x-axis by -pi/2 radians and translation along x-axis by -1 unit
%
% See also: RP2T
%

if ( ~parIsMatrix(T,4,4) ) rethrow(geterr('argValT','T')); end

T = invt(T);
